==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/OktaSignOnPolicyRuleActions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.OktaSignOnPolicyRuleSignonActions;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * OktaSignOnPolicyRuleActions
 */
@JsonPropertyOrder({ OktaSignOnPolicyRuleActions.JSON_PROPERTY_SIGNON })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class OktaSignOnPolicyRuleActions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SIGNON = "signon";
    private OktaSignOnPolicyRuleSignonActions signon;

    public OktaSignOnPolicyRuleActions() {
    }

    public OktaSignOnPolicyRuleActions signon(OktaSignOnPolicyRuleSignonActions signon) {

        this.signon = signon;
        return this;
    }

    /**
     * Get signon
     *
     * @return signon
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SIGNON)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OktaSignOnPolicyRuleSignonActions getSignon() {
        return signon;
    }

    @JsonProperty(JSON_PROPERTY_SIGNON)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSignon(OktaSignOnPolicyRuleSignonActions signon) {
        this.signon = signon;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OktaSignOnPolicyRuleActions oktaSignOnPolicyRuleActions = (OktaSignOnPolicyRuleActions) o;
        return Objects.equals(this.signon, oktaSignOnPolicyRuleActions.signon);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(signon);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OktaSignOnPolicyRuleActions {\n");
        sb.append("    signon: ").append(toIndentedString(signon)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/OktaSignOnPolicyRuleActions.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.OktaSignOnPolicyRuleSignonActions;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * OktaSignOnPolicyRuleActions
 */
@JsonPropertyOrder({ OktaSignOnPolicyRuleActions.JSON_PROPERTY_SIGNON })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class OktaSignOnPolicyRuleActions implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SIGNON = "signon";
    private OktaSignOnPolicyRuleSignonActions signon;

    public OktaSignOnPolicyRuleActions() {
    }

    public OktaSignOnPolicyRuleActions signon(OktaSignOnPolicyRuleSignonActions signon) {

        this.signon = signon;
        return this;
    }

    /**
     * Get signon
     *
     * @return signon
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SIGNON)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public OktaSignOnPolicyRuleSignonActions getSignon() {
        return signon;
    }

    @JsonProperty(JSON_PROPERTY_SIGNON)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSignon(OktaSignOnPolicyRuleSignonActions signon) {
        this.signon = signon;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OktaSignOnPolicyRuleActions oktaSignOnPolicyRuleActions = (OktaSignOnPolicyRuleActions) o;
        return Objects.equals(this.signon, oktaSignOnPolicyRuleActions.signon);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(signon);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OktaSignOnPolicyRuleActions {\n");
        sb.append("    signon: ").append(toIndentedString(signon)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
